# random_caps
a library for randomly applying uppercase letters in a string

## installation
Windows:
```
$ py -m pip install random_caps
```

Linux:
```
$ python3 -m pip install random_caps
```

## example

```python
>>> import random_caps
>>> print(random_caps("random", 2))
"RanDOm"
```